@@ -2,7 +2,7 @@
 from tf_geometric.layers.conv.gcn import GCN
 from tf_geometric.layers.conv.gat import GAT
 from tf_geometric.layers.conv.gin import GIN
-from tf_geometric.layers.conv.graph_sage import MeanGraphSage, MeanPoolGraphSage, MaxPoolGraphSage, GCNGraphSage, LSTMGraphSage
+from tf_geometric.layers.conv.graph_sage import MeanGraphSage, SumGraphSage, MeanPoolGraphSage, MaxPoolGraphSage, GCNGraphSage, LSTMGraphSage
 from tf_geometric.layers.conv.sgc import SGC
 from tf_geometric.layers.conv.tagcn import TAGCN
 from tf_geometric.layers.conv.chebynet import ChebyNet
@@ -19,3 +19,4 @@ from tf_geometric.layers.pool.set2set import Set2Set
 from tf_geometric.layers.pool.sag_pool import SAGPool
 from tf_geometric.layers.pool.asap import ASAP
 from tf_geometric.layers.pool.sort_pool import SortPool
+from tf_geometric.layers.pool.min_cut_pool import MinCutPool
